@@ -1,6 +1,6 @@
 package Pcore::API::DockerHub;
 
-use Pcore -const, -class, -result, -export => { DOCKERHUB_SOURCE_TYPE => [qw[$DOCKERHUB_SOURCE_TYPE_TAG $DOCKERHUB_SOURCE_TYPE_BRANCH]] };
+use Pcore -const, -class, -res, -export => { DOCKERHUB_SOURCE_TYPE => [qw[$DOCKERHUB_SOURCE_TYPE_TAG $DOCKERHUB_SOURCE_TYPE_BRANCH]] };
 use Pcore::Util::Scalar qw[is_plain_coderef];
 
 has username => ( is => 'ro', isa => Str, required => 1 );
@@ -78,8 +78,8 @@ sub _login ( $self, $cb ) {
     );
 }
 
-sub _req ( $self, $method, $endpoint, $require_auth, $data, $cb ) {
-    my $blocking_cv = defined wantarray ? AE::cv : undef;
+sub _req ( $self, $method, $endpoint, $require_auth, $data, $cb = undef ) {
+    my $rouse_cb = defined wantarray ? Coro::rouse_cb : ();
 
     my $request = sub {
         P->http->$method(
@@ -90,15 +90,15 @@ sub _req ( $self, $method, $endpoint, $require_auth, $data, $cb ) {
             },
             body => $data ? P->data->to_json($data) : undef,
             sub ($res) {
-                my $api_res = result [ $res->status, $res->reason ], $res->body && $res->body->$* ? P->data->from_json( $res->body ) : ();
+                my $api_res = res [ $res->status, $res->reason ], $res->body && $res->body->$* ? P->data->from_json( $res->body ) : ();
 
-                $cb->($api_res) if $cb;
-
-                $blocking_cv->send($api_res) if $blocking_cv;
+                $rouse_cb ? $cb ? $rouse_cb->( $cb->($api_res) ) : $rouse_cb->($api_res) : $cb ? $cb->($api_res) : ();
 
                 return;
             }
         );
+
+        return;
     };
 
     if ( !$require_auth ) {
@@ -117,16 +117,14 @@ sub _req ( $self, $method, $endpoint, $require_auth, $data, $cb ) {
 
             # login failure
             else {
-                $cb->($res) if $cb;
-
-                $blocking_cv->send($res) if $blocking_cv;
+                $rouse_cb ? $cb ? $rouse_cb->( $cb->($res) ) : $rouse_cb->($res) : $cb ? $cb->($res) : ();
             }
 
             return;
         } );
     }
 
-    return $blocking_cv ? $blocking_cv->recv : ();
+    return $rouse_cb ? Coro::rouse_wait $rouse_cb : ();
 }
 
 # USER / NAMESPACE
@@ -154,9 +152,7 @@ sub get_user_orgs ( $self, $cb = undef ) {
                 $res->{data} = $data;
             }
 
-            $cb->($res) if $cb;
-
-            return;
+            return $cb ? $cb->($res) : $res;
         }
     );
 }
@@ -260,9 +256,7 @@ sub get_all_repos ( $self, $namespace, $cb = undef ) {
                 $res->{data} = $data;
             }
 
-            $cb->($res) if $cb;
-
-            return;
+            return $cb ? $cb->($res) : $res;
         }
     );
 }
@@ -277,9 +271,7 @@ sub get_repo ( $self, $repo_id, $cb = undef ) {
                 $res->{data}->{id} = $repo_id;
             }
 
-            $cb->($res) if $cb;
-
-            return;
+            return $cb ? $cb->($res) : $res;
         }
     );
 }
@@ -314,9 +306,7 @@ sub get_tags ( $self, $repo_id, $cb = undef ) {
                 $res->{data} = $data;
             }
 
-            $cb->($res) if $cb;
-
-            return;
+            return $cb ? $cb->($res) : $res;
         }
     );
 }
@@ -368,9 +358,7 @@ sub get_autobuild_links ( $self, $repo_id, $cb = undef ) {
                 $res->{data} = $data;
             }
 
-            $cb->($res) if $cb;
-
-            return;
+            return $cb ? $cb->($res) : $res;
         }
     );
 }
@@ -403,9 +391,7 @@ sub get_build_history ( $self, $repo_id, $cb = undef ) {
                 $res->{data} = $data;
             }
 
-            $cb->($res) if $cb;
-
-            return;
+            return $cb ? $cb->($res) : $res;
         }
     );
 }
@@ -415,16 +401,14 @@ sub get_autobuild_settings ( $self, $repo_id, $cb = undef ) {
 }
 
 sub unlink_tag ( $self, $repo_id, $tag_name, $cb = undef ) {
-    my $blocking_cv = defined wantarray ? AE::cv : undef;
+    my $rouse_cb = defined wantarray ? Coro::rouse_cb : ();
 
     my ( $delete_autobuild_tag_status, $delete_tag_status );
 
     my $cv = AE::cv {
-        my $res = result [ 200, "autobuild: $delete_autobuild_tag_status->{reason}, tag: $delete_tag_status->{reason}" ];
+        my $res = res [ 200, "autobuild: $delete_autobuild_tag_status->{reason}, tag: $delete_tag_status->{reason}" ];
 
-        $cb->($res) if $cb;
-
-        $blocking_cv->($res) if $blocking_cv;
+        $rouse_cb ? $cb ? $rouse_cb->( $cb->($res) ) : $rouse_cb->($res) : $cb ? $cb->($res) : ();
 
         return;
     };
@@ -459,7 +443,7 @@ sub unlink_tag ( $self, $repo_id, $tag_name, $cb = undef ) {
 
     $cv->end;
 
-    return $blocking_cv ? $blocking_cv->recv : ();
+    return $rouse_cb ? Coro::rouse_wait $rouse_cb : ();
 }
 
 # AUTOBUILD TAGS
@@ -479,9 +463,7 @@ sub get_autobuild_tags ( $self, $repo_id, $cb = undef ) {
                 $res->{data} = $data;
             }
 
-            $cb->($res) if $cb;
-
-            return;
+            return $cb ? $cb->($res) : $res;
         }
     );
 }
@@ -510,12 +492,10 @@ sub delete_autobuild_tag_by_id ( $self, $repo_id, $autobuild_tag_id, $cb = undef
 }
 
 sub delete_autobuild_tag_by_name ( $self, $repo_id, $autobuild_tag_name, $cb = undef ) {
-    my $blocking_cv = defined wantarray ? AE::cv : undef;
+    my $rouse_cb = defined wantarray ? Coro::rouse_cb : ();
 
     my $on_finish = sub ($res) {
-        $cb->($res) if $cb;
-
-        $blocking_cv->($res) if $blocking_cv;
+        $rouse_cb ? $cb ? $rouse_cb->( $cb->($res) ) : $rouse_cb->($res) : $cb ? $cb->($res) : ();
 
         return;
     };
@@ -539,7 +519,7 @@ sub delete_autobuild_tag_by_name ( $self, $repo_id, $autobuild_tag_name, $cb = u
                 }
 
                 if ( !$found_autobuild_tag ) {
-                    $on_finish->( result [ 404, 'Autobuild tag was not found' ] );
+                    $on_finish->( res [ 404, 'Autobuild tag was not found' ] );
                 }
                 else {
                     $self->delete_autobuild_tag_by_id( $repo_id, $found_autobuild_tag->{id}, $on_finish );
@@ -550,7 +530,7 @@ sub delete_autobuild_tag_by_name ( $self, $repo_id, $autobuild_tag_name, $cb = u
         }
     );
 
-    return $blocking_cv ? $blocking_cv->recv : ();
+    return $rouse_cb ? Coro::rouse_wait $rouse_cb : ();
 }
 
 sub trigger_autobuild ( $self, $repo_id, $source_name, $source_type, $cb = undef ) {
@@ -567,12 +547,10 @@ sub trigger_autobuild ( $self, $repo_id, $source_name, $source_type, $cb = undef
 }
 
 sub trigger_autobuild_by_tag_name ( $self, $repo_id, $autobuild_tag_name, $cb = undef ) {
-    my $blocking_cv = defined wantarray ? AE::cv : undef;
+    my $rouse_cb = defined wantarray ? Coro::rouse_cb : ();
 
     my $on_finish = sub ($res) {
-        $cb->($res) if $cb;
-
-        $blocking_cv->($res) if $blocking_cv;
+        $rouse_cb ? $cb ? $rouse_cb->( $cb->($res) ) : $rouse_cb->($res) : $cb ? $cb->($res) : ();
 
         return;
     };
@@ -596,7 +574,7 @@ sub trigger_autobuild_by_tag_name ( $self, $repo_id, $autobuild_tag_name, $cb =
                 }
 
                 if ( !$found_autobuild_tag ) {
-                    $on_finish->( result [ 404, 'Autobuild tag was not found' ] );
+                    $on_finish->( res [ 404, 'Autobuild tag was not found' ] );
                 }
                 else {
                     $self->trigger_autobuild( $repo_id, $found_autobuild_tag->{source_name}, $found_autobuild_tag->{source_type}, $on_finish );
@@ -607,7 +585,7 @@ sub trigger_autobuild_by_tag_name ( $self, $repo_id, $autobuild_tag_name, $cb =
         }
     );
 
-    return $blocking_cv ? $blocking_cv->recv : ();
+    return $rouse_cb ? Coro::rouse_wait $rouse_cb : ();
 }
 
 1;
@@ -617,12 +595,12 @@ sub trigger_autobuild_by_tag_name ( $self, $repo_id, $autobuild_tag_name, $cb =
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 81, 190, 324, 334,   | Subroutines::ProhibitManyArgs - Too many arguments                                                             |
-## |      | 350, 378, 382, 417,  |                                                                                                                |
-## |      | 489, 508, 512, 556,  |                                                                                                                |
-## |      | 569                  |                                                                                                                |
+## |    3 | 81, 186, 314, 324,   | Subroutines::ProhibitManyArgs - Too many arguments                                                             |
+## |      | 340, 366, 370, 403,  |                                                                                                                |
+## |      | 471, 490, 494, 536,  |                                                                                                                |
+## |      | 549                  |                                                                                                                |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    1 | 168                  | CodeLayout::RequireTrailingCommas - List declaration without trailing comma                                    |
+## |    1 | 164                  | CodeLayout::RequireTrailingCommas - List declaration without trailing comma                                    |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
