@@ -3,12 +3,10 @@ package Pcore::Util::CA;
 use Pcore -class;
 
 sub update ($cb = undef) {
-    my $blocking_cv = defined wantarray ? AE::cv : undef;
+    my $rouse_cb = defined wantarray ? Coro::rouse_cb : ();
 
     print 'updating ca_file.pem ... ';
 
-    require Pcore::HTTP;
-
     P->http->get(
         'https://curl.haxx.se/ca/cacert.pem',
         sub ($res) {
@@ -25,15 +23,13 @@ sub update ($cb = undef) {
                 say 'error';
             }
 
-            $cb->($status) if $cb;
-
-            $blocking_cv->($status) if $blocking_cv;
+            $rouse_cb ? $cb ? $rouse_cb->( $cb->($status) ) : $rouse_cb->($status) : $cb ? $cb->($status) : ();
 
             return;
         }
     );
 
-    return $blocking_cv ? $blocking_cv->recv : ();
+    return $rouse_cb ? Coro::rouse_wait $rouse_cb : ();
 }
 
 sub ca_file {
